// Copyright (C) 2025 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import m from 'mithril';
import {Checkbox} from '../../../widgets/checkbox';
import {EnumOption, renderWidgetShowcase} from '../widgets_page_utils';

export function renderCheckbox(): m.Children {
  return [
    m(
      '.pf-widget-intro',
      m('h1', 'Checkbox'),
      m(
        'p',
        'A standard checkbox input for binary on/off selections with optional labels and disabled state.',
      ),
    ),
    renderWidgetShowcase({
      renderWidget: ({label, labelLeft, showInlineText, ...opts}) => [
        showInlineText && 'Before',
        m(Checkbox, {
          label: label ? 'Checkbox' : undefined,
          labelLeft: labelLeft ? 'Checkbox' : undefined,
          ...opts,
        }),
        showInlineText && 'after',
      ],
      initialOpts: {
        label: true,
        labelLeft: false,
        disabled: false,
        variant: new EnumOption('checkbox', ['checkbox', 'switch'] as const),
        showInlineText: false,
      },
    }),
  ];
}
